@@ -1,4 +1,4 @@
-/* LOCKVC Version 3.4 (c) 1994, 1995, 1997 by Matthias Straub */
+/* LOCKVC Version 3.0 (c) 1994, 1995, 1997 by Matthias Straub */
 /* shadow-password option added by Ed Beaumont */
 /* integer math derived from a patch by Jeff Epler */
 /* this file was released under GPL */
@@ -8,9 +8,11 @@
 #include <time.h>
 #include <string.h>
 
+#include "lockvc.h"
+
 #define ANZSAVER 4
 
-mod_choose(int argc, char **argv, int *saver)
+void mod_choose(int argc, char **argv, int *saver)
 {       
 
     *saver=time(NULL)%ANZSAVER;
@@ -34,7 +36,7 @@ mod_choose(int argc, char **argv, int *saver)
     }       
 } 
         
-mod_start(int argc, char **argv,int *saver)
+void mod_start(int argc, char **argv,int *saver)
 {
 	switch (*saver)
 	{
