@@ -1,4 +1,4 @@
-/* LOCKVC Version 3.4 (c) 1994, 1995, 1997 by Matthias Straub */
+/* LOCKVC Version 3.6 (c) 1994, 1995, 1997 by Matthias Straub */
 /* shadow-password option added by Ed Beaumont */
 /* integer math derived from a patch by Jeff Epler */
 /* this file was released under GPL */
@@ -21,6 +21,10 @@
 
 #include <math.h> 
 #include <vga.h>
+#include <stdlib.h>
+#include <stdio.h>
+
+#include "lockvc.h"
 
 struct field 
 {
@@ -133,7 +137,7 @@ void plotfield(struct field *feld)
         
 void starfield(int argc, char **argv)
 {
-    int i,j;
+    int j;
     static struct field this;
 
 
